@@ -112,7 +112,11 @@ def get_handler(debug=False, syslog=False, logfile=None, rotation_parameters=Non
     else:
         try:
             if rotation_parameters is None:
-                handler = logging.FileHandler(logfile)
+                if os.name == 'posix' and sys.version_info >= (2, 6):
+                    from logging.handlers import WatchedFileHandler
+                    handler = WatchedFileHandler(logfile)
+                else:
+                    handler = logging.FileHandler(logfile)
             else:
                 from logging.handlers import TimedRotatingFileHandler
                 handler = TimedRotatingFileHandler(
