@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -71,7 +71,8 @@ class ProcInfo(Node):
             return 0
 
     def lineage_memory_usage(self):
-        return self.memory_usage() + sum(child.lineage_memory_usage() for child in self.children)
+        return self.memory_usage() + sum([child.lineage_memory_usage()
+                                          for child in self.children])
 
     def time(self, children=0):
         """return the number of jiffies that this process has been scheduled
