@@ -1,4 +1,4 @@
-# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -117,7 +117,7 @@ class ProgressBarTC(TestCase):
             pgb.update()
             if update or (update is None and dots != last):
                 last = dots
-                expected_stream.write("\r["+('.'*dots)+(' '*(size-dots))+"]")
+                expected_stream.write("\r["+('='*dots)+(' '*(size-dots))+"]")
             self.assertEqual(pgb_stream.getvalue(), expected_stream.getvalue())
 
     def test_default(self):
@@ -144,6 +144,30 @@ class ProgressBarTC(TestCase):
     def test_overflow(self):
         self._update_test(5, (8, 16, 25, 33, 42, (42, True)), size=42)
 
+    def test_update_exact(self):
+        pgb_stream = StringIO()
+        expected_stream = StringIO()
+        size=20
+        pgb = ProgressBar(100, size, stream=pgb_stream)
+        last = 0
+        for dots in xrange(10, 105, 15):
+            pgb.update(dots, exact=True)
+            dots //= 5
+            expected_stream.write("\r["+('='*dots)+(' '*(size-dots))+"]")
+            self.assertEqual(pgb_stream.getvalue(), expected_stream.getvalue())
+
+    def test_update_relative(self):
+        pgb_stream = StringIO()
+        expected_stream = StringIO()
+        size=20
+        pgb = ProgressBar(100, size, stream=pgb_stream)
+        last = 0
+        for dots in xrange(5, 105, 5):
+            pgb.update(5, exact=False)
+            dots //= 5
+            expected_stream.write("\r["+('='*dots)+(' '*(size-dots))+"]")
+            self.assertEqual(pgb_stream.getvalue(), expected_stream.getvalue())
+
 
 class AcquireLockTC(TestCase):
 
