@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -121,29 +121,6 @@ class TestlibTC(TestCase):
         invalid = """<root><h2 </h2> </root>"""
         self.assertRaises(AssertionError, self.tc.assertXMLStringWellFormed, invalid)
 
-    def test_unordered_equality_for_lists(self):
-        l1 = [0, 1, 2]
-        l2 = [1, 2, 3]
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, l1, l2)
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, l1, l2)
-        self.tc.assertItemsEqual(l1, l1)
-        self.tc.assertItemsEqual(l1, l1)
-        self.tc.assertItemsEqual([], [])
-        self.tc.assertItemsEqual([], [])
-        l1 = [0, 1, 1]
-        l2 = [0, 1]
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, l1, l2)
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, l1, l2)
-        self.tc.assertItemsEqual(l1, l1)
-        self.tc.assertItemsEqual(l1, l1)
-
-    def test_unordered_equality_for_dicts(self):
-        d1 = {'a' : 1, 'b' : 2}
-        d2 = {'a' : 1}
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, d1, d2)
-        self.tc.assertItemsEqual(d1, d1)
-        self.tc.assertItemsEqual({}, {})
-
     def test_equality_for_sets(self):
         s1 = set('ab')
         s2 = set('a')
@@ -151,14 +128,6 @@ class TestlibTC(TestCase):
         self.tc.assertSetEqual(s1, s1)
         self.tc.assertSetEqual(set(), set())
 
-    def test_unordered_equality_for_iterables(self):
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, xrange(5), xrange(6))
-        self.assertRaises(AssertionError, self.tc.assertItemsEqual, xrange(5), xrange(6))
-        self.tc.assertItemsEqual(xrange(5), range(5))
-        self.tc.assertItemsEqual(xrange(5), range(5))
-        self.tc.assertItemsEqual([], ())
-        self.tc.assertItemsEqual([], ())
-
     def test_file_equality(self):
         foo = join(dirname(__file__), 'data', 'foo.txt')
         spam = join(dirname(__file__), 'data', 'spam.txt')
@@ -235,10 +204,6 @@ class TestlibTC(TestCase):
         # class' custom datadir
         tc = MyTC('test_1')
         self.assertEqual(tc.datapath('bar'), join('foo', 'bar'))
-        # instance's custom datadir
-        self.skipTest('should this really work?')
-        tc.datadir = 'spam'
-        self.assertEqual(tc.datapath('bar'), join('spam', 'bar'))
 
     def test_cached_datadir(self):
         """test datadir is cached on the class"""
@@ -663,6 +628,17 @@ class DecoratorTC(TestCase):
         self.assertListEqual(list(os.walk(tempdir)),
             [(tempdir, [], [])])
 
+    def test_tmpdir_generator(self):
+        orig_tempdir = tempfile.gettempdir()
+
+        @with_tempdir
+        def gen():
+            yield tempfile.gettempdir()
+
+        for tempdir in gen():
+            self.assertNotEqual(orig_tempdir, tempdir)
+        self.assertEqual(orig_tempdir, tempfile.gettempdir())
+
     def setUp(self):
         self.pyversion = sys.version_info
 
@@ -788,6 +764,9 @@ class TagTC(TestCase):
         self.assertTrue(tags.match('other or (testing and bob)'))
 
     def test_tagged_class(self):
+        if sys.version_info > (3, 0):
+            self.skipTest('fix me for py3k')
+
         def options(tags):
             class Options(object):
                 tags_pattern = tags
