@@ -550,6 +550,9 @@ class TestCase(unittest.TestCase):
             func(*args, **kwargs)
         except (KeyboardInterrupt, SystemExit):
             raise
+        except unittest.SkipTest, e:
+            self._addSkip(result, str(e))
+            return False
         except:
             result.addError(self, self.__exc_info())
             return False
@@ -1187,6 +1190,9 @@ succeeded test into", osp.join(os.getcwd(), FILE_RESTART)
         assertItemsEqual = unittest.TestCase.assertCountEqual
     else:
         assertCountEqual = unittest.TestCase.assertItemsEqual
+        if sys.version_info < (2,7):
+            def assertIsNotNone(self, value, *args, **kwargs):
+                self.assertNotEqual(None, value, *args, **kwargs)
 
 TestCase.assertItemsEqual = deprecated('assertItemsEqual is deprecated, use assertCountEqual')(
     TestCase.assertItemsEqual)
