@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-common.
@@ -46,6 +46,7 @@ __docformat__ = "restructuredtext en"
 import sys
 import re
 import os.path as osp
+from warnings import warn
 from unicodedata import normalize as _uninormalize
 try:
     from os import linesep
@@ -71,7 +72,7 @@ MANUAL_UNICODE_MAP = {
     u'\xdf': u'ss',   # LATIN SMALL LETTER SHARP S
     }
 
-def unormalize(ustring, ignorenonascii=False):
+def unormalize(ustring, ignorenonascii=None, substitute=None):
     """replace diacritical characters with their corresponding ascii characters
 
     Convert the unicode string to its long normalized form (unicode character
@@ -79,19 +80,28 @@ def unormalize(ustring, ignorenonascii=False):
     The normal form KD (NFKD) will apply the compatibility decomposition, i.e.
     replace all compatibility characters with their equivalents.
 
+    :type substitute: str
+    :param substitute: replacement character to use if decomposition fails
+
     :see: Another project about ASCII transliterations of Unicode text
           http://pypi.python.org/pypi/Unidecode
     """
+    # backward compatibility, ignorenonascii was a boolean
+    if ignorenonascii is not None:
+        warn("ignorenonascii is deprecated, use substitute named parameter instead",
+             DeprecationWarning, stacklevel=2)
+        if ignorenonascii:
+            substitute = ''
     res = []
     for letter in ustring[:]:
         try:
             replacement = MANUAL_UNICODE_MAP[letter]
         except KeyError:
-            if ord(letter) >= 2**8:
-                if ignorenonascii:
-                    continue
-                raise ValueError("can't deal with non-ascii based characters")
             replacement = _uninormalize('NFKD', letter)[0]
+            if ord(replacement) >= 2 ** 7:
+                if substitute is None:
+                    raise ValueError("can't deal with non-ascii based characters")
+                replacement = substitute
         res.append(replacement)
     return u''.join(res)
 
@@ -303,6 +313,8 @@ _BLANK_RE = re.compile(_BLANK_URE)
 __VALUE_URE = r'-?(([0-9]+\.[0-9]*)|((0x?)?[0-9]+))'
 __UNITS_URE = r'[a-zA-Z]+'
 _VALUE_RE = re.compile(r'(?P<value>%s)(?P<unit>%s)?'%(__VALUE_URE, __UNITS_URE))
+_VALIDATION_RE = re.compile(r'^((%s)(%s))*(%s)?$' % (__VALUE_URE, __UNITS_URE,
+                                                    __VALUE_URE))
 
 BYTE_UNITS = {
     "b": 1,
@@ -320,8 +332,8 @@ TIME_UNITS = {
     "d": 60 * 60 *24,
 }
 
-def apply_units( string, units, inter=None, final=float, blank_reg=_BLANK_RE,
-    value_reg=_VALUE_RE):
+def apply_units(string, units, inter=None, final=float, blank_reg=_BLANK_RE,
+                value_reg=_VALUE_RE):
     """Parse the string applying the units defined in units
     (e.g.: "1.5m",{'m',60} -> 80).
 
@@ -342,12 +354,12 @@ def apply_units( string, units, inter=None, final=float, blank_reg=_BLANK_RE,
     """
     if inter is None:
         inter = final
-    string = _BLANK_RE.sub('', string)
+    fstring = _BLANK_RE.sub('', string)
+    if not (fstring and _VALIDATION_RE.match(fstring)):
+        raise ValueError("Invalid unit string: %r." % string)
     values = []
-    for match in value_reg.finditer(string):
+    for match in value_reg.finditer(fstring):
         dic = match.groupdict()
-        #import sys
-        #print >> sys.stderr, dic
         lit, unit = dic["value"], dic.get("unit")
         value = inter(lit)
         if unit is not None:
